==> ideaIC-2019.3-sources.jar: com/android/tools/idea/uibuilder/handlers/motion/Debug.java <==
/*
 * Copyright (C) 2018 The Android Open Source Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.android.tools.idea.uibuilder.handlers.motion;

public class Debug {
  private static int max;

  public static final void println(String str) {
    StackTraceElement st = new Throwable().getStackTrace()[1];
    String s = ".(" + st.getFileName() + ":" + (st.getLineNumber()) + ")";
    max = Math.max(max, s.length() + 3);
    s = "> " + s + new String(new char[max - s.length()]).replace('\0', ' ');
    s = s.substring(0, max);
    System.out.println(s + " | " + str);
  }

  public static final void println(int n, String str) {
    StackTraceElement[] st = new Throwable().getStackTrace();
    for (int i = Math.min(st.length - 1, n); i > 0; i--) {
      StackTraceElement element = st[i];
      String s = ".(" + element.getFileName() + ":" + (element.getLineNumber()) + ")";
      max = Math.max(max, s.length() + 3);
      s = "> " + s + new String(new char[max - s.length()]).replace('\0', ' ');
      s = s.substring(0, max);
      System.out.println(s + " : " + ((i == 1) ? str : (element.getMethodName()+"()")));
    }
  }
}

==> ideaIC-2021.1.1-sources.jar: com/android/tools/idea/uibuilder/handlers/motion/Debug.java <==
/*
 * Copyright (C) 2018 The Android Open Source Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.android.tools.idea.uibuilder.handlers.motion;

public class Debug {
  private static int max;

  public static final void println(String str) {
    StackTraceElement st = new Throwable().getStackTrace()[1];
    String s = ".(" + st.getFileName() + ":" + (st.getLineNumber()) + ")";
    max = Math.max(max, s.length() + 3);
    s = "> " + s + new String(new char[max - s.length()]).replace('\0', ' ');
    s = s.substring(0, max);
    System.out.println(s + " | " + str);
  }

  public static final void println(int n, String str) {
    StackTraceElement[] st = new Throwable().getStackTrace();
    for (int i = Math.min(st.length - 1, n); i > 0; i--) {
      StackTraceElement element = st[i];
      String s = ".(" + element.getFileName() + ":" + (element.getLineNumber()) + ") "+element.getMethodName()+"()";
      max = Math.max(max, s.length() + 3);
      s = "> " + s + new String(new char[max - s.length()]).replace('\0', ' ');
      s = s.substring(0, max);
      System.out.println(s + " : " + ((i == 1) ? str : (element.getMethodName()+"()")));
    }
  }
}
